@@ -59,7 +59,8 @@ where
                         table.push(l);
                         l
                     })
-            }).collect_vec();
+            })
+            .collect_vec();
         let &idx = idxs.iter().min().unwrap_or(&usize::MAX);
         for i in idxs {
             if i != idx {
@@ -81,7 +82,8 @@ where
                 } else {
                     get_and_redirect(&mut table, i)
                 }
-            }).collect(),
+            })
+            .collect(),
     )
 }
 
@@ -109,7 +111,8 @@ where
             gs.map(|(i, _)| groups[i].clone())
                 .flat_map(|i| i)
                 .collect::<HashSet<_>>()
-        }).collect()
+        })
+        .collect()
 }
 
 /// Extract connected components from a graph.
@@ -133,7 +136,8 @@ where
                     .into_iter()
                     .chain(once(s.clone()))
                     .collect_vec()
-            }).collect_vec(),
+            })
+            .collect_vec(),
     )
 }
 
