@@ -51,7 +51,8 @@ fn tryalgo_examples() {
             [287, 63, 343, 169, 583],
             [627, 343, 773, 959, 943],
             [767, 473, 103, 699, 303],
-        ]).0,
+        ])
+        .0,
         3315
     );
 }
